@@ -1,5 +1,5 @@
 def findMonomialDegree(x):
-  for character in x:
+  for character in str(x):
     if character.isdigit(0):
       print("Constant")
     if character.isdigit(1):
