@@ -4,4 +4,4 @@ def findSlope(x, y):
   print("Slope is " + xToString + "/ " + yToString)
 
 def slopeIntercept(x, y):
-  print("y = " + x + "x + " + y)
\ No newline at end of file
+  print("y = " + str(x) + "x + " + str(y))
\ No newline at end of file
